package de.mpg.mpimet.yacgui.xml;

/**
 * Copyright (c) 2013 Max-Planck-Institute for Meteorology, Hamburg.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 *   - Neither the name of Oracle or the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Java representation of {@code <transient_grid_ref>} xml element.
 * 
 * @author Maxim Yastremsky, Teresa Holfeld
 */

public class TransientGridRef implements Comparable<TransientGridRef> {
	
	/** ID of this TransientGridRef */
	private int id;
	
	/** ID of references Transient */
	private int transientRef;
	
	/** ID of references Grid */
	private int gridRef;
	
	/** Collection size */
	private int collectionSize;
	
	/**
	 * Creates a TransientGridRef object with id, transientRef and usersGrid.
	 * 
	 * @param id			 ID of this TransientGridRef
	 * @param transientRef	 ID of referenced Transient 
	 * @param gridRef		 ID of referenced Grid
	 * @param collectionSize number of phyical fields of vertival levels in transient
	 */
	public TransientGridRef(int id, int transientRef, int gridRef, int collectionSize) {
		this.id = id;
		this.transientRef = transientRef;
		this.gridRef = gridRef;
		this.collectionSize = collectionSize;
	}
	
	/**
	 * @return id: ID of this TransientGridRef.
	 */
	public int getId() {
		return id;
	}

	/**
	 * @return transientRef: ID of referenced Transient.
	 */
	public int getTransientRef() {
		return transientRef;
	}
	
	public void setTransientRef(int transientRef) {
		this.transientRef = transientRef;
	}

	/**
	 * @return gridRef: ID of referenced Grid.
	 */
	public int getGridRef() {
		return gridRef;
	}
	
	public void setGridRef(int gridRef) {
		this.gridRef = gridRef;
	}
	
	/**
	 * @return collectionSize
	 */
	public int getCollectionSize() {
		return collectionSize;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + gridRef;
		result = prime * result + id;
		result = prime * result + transientRef;
		result = prime * result + collectionSize;
		return result;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (!(obj instanceof TransientGridRef)) {
			return false;
		}
		TransientGridRef other = (TransientGridRef) obj;
		if (gridRef != other.gridRef) {
			return false;
		}
		if (id != other.id) {
			return false;
		}
		if (transientRef != other.transientRef) {
			return false;
		}
		if (collectionSize != other.collectionSize) {
			return false;
		}
		return true;
	}
	
	@Override
	public int compareTo(TransientGridRef o) {
		return id - o.id;
	}
}
