package de.mpg.mpimet.yacgui.xml.interpolation;

import de.mpg.mpimet.yacgui.xml.Dom;
import de.mpg.mpimet.yacgui.xml.interpolation.WeightMethods.Weighted;

/**
 * Copyright (c) 2013 Max-Planck-Institute for Meteorology, Hamburg.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 *   - Neither the name of Oracle or the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Definite interpolation method average
 * 
 * @author Maxim Yastremsky
 */

public class AverageInterpolation extends Interpolation {

	private boolean partialCoverage;
	private Weighted weighted;
	
	public AverageInterpolation(boolean partialCoverage, Weighted weighted) {
		attributesNumber = 2;
		method = InterpolationMethod.AVERAGE;
		this.partialCoverage = partialCoverage;
		this.weighted = weighted;
	}
	
	/**
	 * 
	 * @return true if partial coverage is active
	 */
	public boolean getPartialCoverage() {
		return partialCoverage;
	}
	
	/**
	 * 
	 * @return object of {@link Weighted} indicating method of weighted
	 */
	public Weighted getWeighted() {
		return weighted;
	}
	
	/**
	 * get attribute name by the order of index
	 * @param index the order of attributes on the panel
	 * @return  the name of attribute
	 * 				if 0 return PARTIAL_COVERAGE, if 1 return WEIGHTED
	 */
	public String getAttributeName(int index) {
		if (index == 0) {
			return Dom.Attribute.PARTIAL_COVERAGE;
		} else if (index == 1) {
			return Dom.Attribute.WEIGHTED;
		}
		return null;
	}
	
	/**
	 * get attribute value by the order of index
	 * @param index the order of attributes on the panel
	 * @return the value of attribute as String
	 * 				if 0 return partialCoverage, if 1 return weighted
	 */
	public String getAttributeValue(int index) {
		if (index == 0) {
			return String.valueOf(partialCoverage);
		} else if (index == 1) {
			return weighted.toString();
		}
		return null;
	}
}
