package de.mpg.mpimet.yacgui.xml.interpolation;

import de.mpg.mpimet.yacgui.xml.Dom;
import de.mpg.mpimet.yacgui.xml.interpolation.WeightMethods.Weighted;

/**
 * Copyright (c) 2021 Max-Planck-Institute for Meteorology, Hamburg.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   - Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 *   - Neither the name of Oracle or the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Define interpolation method source to target mapping
 * 
 * @author Rene Redler
 */

public class Source2TargetMapInterpolation extends Interpolation {

        private Weighted weighted;
        private double spreadDistance;
        private double maxSearchDistance;

        public Source2TargetMapInterpolation ( double spreadDistance , double maxSearchDistance , Weighted weighted ) {
                attributesNumber = 3;
		method = InterpolationMethod.SOURCE2TARGET_MAP;
                this.spreadDistance = spreadDistance;
                this.maxSearchDistance = maxSearchDistance;
                this.weighted = weighted;
        }

        /**
         *
         * @return object of {@link Weighted} indicating method of weighted
         */
        public Weighted getWeighted() {
                return weighted;
        }

        /**
         *
         * @return object of {@link double} indicating value of spread distance
         */
        public double getSpreadDistance() {
                return spreadDistance;
        }

        /**
         *
         * @return object of {@link double} indicating value of maximum search distance
         */
        public double getMaxSearchDistance() {
                return maxSearchDistance;
        }

        /**
         * get attribute name by the order of index
         * @param index the order of attributes on the panel
         * @return  the name of attribute
         *                              if 0 return SPREAD_DISTANCE, if 1 return MAX_SEARCH_DISTANCE, if 2 return WEIGHTED
         */
        public String getAttributeName(int index) {
                if (index == 0) {
                        return Dom.Attribute.SPREAD_DISTANCE;
                } else if (index == 1) {
                        return Dom.Attribute.MAX_SEARCH_DISTANCE;
                } else if (index == 2) {
                        return Dom.Attribute.WEIGHTED;
                }
                return null;
        }

        /**
         * get attribute value by the order of index
         * @param index the order of attributes on the panel
         * @return the value of attribute as String
         *                              if 0 return spreadDistance, if 1 return maxSearchDistance , if 2 return weighted
         */
        public String getAttributeValue(int index) {
                if (index == 0) {
                        return String.valueOf(spreadDistance);
                } else if (index == 1) {
                        return String.valueOf(maxSearchDistance);
                } else if (index == 2) {
                        return weighted.toString();
                }
                return null;
        }

}
