!!
!! @file test_get_transients.F90
!!
!! @copyright Copyright  (C)  2021 DKRZ, MPI-M
!!
!! @author Moritz Hanke <hanke@dkrz.de>
!!         Rene Redler  <rene.redler@mpimet.mpg.de>
!!
!
! Keywords:
! Maintainer: Moritz Hanke <hanke@dkrz.de>
!             Rene Redler <rene.redler@mpimet.mpg.de>
! URL: https://dkrz-sw.gitlab-pages.dkrz.de/yac/
!
! This file is part of YAC.
!
! Redistribution and use in source and binary forms, with or without
! modification, are  permitted provided that the following conditions are
! met:
!
! Redistributions of source code must retain the above copyright notice,
! this list of conditions and the following disclaimer.
!
! Redistributions in binary form must reproduce the above copyright
! notice, this list of conditions and the following disclaimer in the
! documentation and/or other materials provided with the distribution.
!
! Neither the name of the DKRZ GmbH nor the names of its contributors
! may be used to endorse or promote products derived from this software
! without specific prior written permission.
!
! THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
! IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
! TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
! PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
! OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
! EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
! PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
! PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
! LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
! NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
! SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
!

#include "test_macros.inc"

program test_get_transients

  use utest
  use mo_yac_finterface
  implicit none

  integer :: comp_ids(3)
  integer :: transient_ids(2)

  character(len=YAC_MAX_CHARLEN) :: comp_names(3)
  character(len=YAC_MAX_CHARLEN) :: xml_name
  character(len=YAC_MAX_CHARLEN) :: schema_name

  call start_test("def_comps")

  comp_ids = -99

  xml_name    = 'coupling.xml'
  schema_name = 'coupling.xsd'
  call yac_finit ( xml_name , schema_name )

  comp_names(1) = 'ICON-ocean'
  comp_names(2) = 'ICON-atmosphere'
  comp_names(3) = '...'
  call yac_fdef_comps ( comp_names, 3, comp_ids )

  call test ( ALL( comp_ids(:) /= -99 ) )

  CALL test(yac_fget_transients_count(comp_ids(1)) == 2)
  CALL yac_fget_transient_ids(comp_ids(1), transient_ids)
  CALL test(yac_fis_transient_source(transient_ids(1)))
  CALL test(.NOT. yac_fis_transient_source(transient_ids(2)))
  CALL test(.NOT. yac_fis_transient_target(transient_ids(1)))
  CALL test(yac_fis_transient_target(transient_ids(2)))
  CALL test(yac_fget_transient_collection_size(transient_ids(1)) == 3)
  CALL test(yac_fget_transient_collection_size(transient_ids(2)) == 4)
  CALL test(yac_fget_transient_coupling_period(transient_ids(1)) == '60')
  CALL test(yac_fget_transient_coupling_period(transient_ids(2)) == '60')
  CALL test(TRIM(yac_fget_transient_source_grid_name(transient_ids(1))) == 'grid1')
  CALL test(TRIM(yac_fget_transient_source_grid_name(transient_ids(2))) == 'grid2')
  CALL test(TRIM(yac_fget_transient_target_grid_name(transient_ids(1))) == 'grid2')
  CALL test(TRIM(yac_fget_transient_target_grid_name(transient_ids(2))) == 'grid3')
  CALL test(TRIM(yac_fget_transient_name(transient_ids(1))) == "sea_surface_temperature")
  CALL test(TRIM(yac_fget_transient_name(transient_ids(2))) == "water_flux_into_sea_water")

  CALL test(yac_fget_transients_count(comp_ids(2)) == 2)
  CALL yac_fget_transient_ids(comp_ids(2), transient_ids)
  CALL test(.NOT. yac_fis_transient_source(transient_ids(1)))
  CALL test(yac_fis_transient_source(transient_ids(2)))
  CALL test(yac_fis_transient_target(transient_ids(1)))
  CALL test(.NOT. yac_fis_transient_target(transient_ids(2)))
  CALL test(yac_fget_transient_collection_size(transient_ids(1)) == 3)
  CALL test(yac_fget_transient_collection_size(transient_ids(2)) == 4)
  CALL test(yac_fget_transient_coupling_period(transient_ids(1)) == '60')
  CALL test(yac_fget_transient_coupling_period(transient_ids(2)) == '60')
  CALL test(TRIM(yac_fget_transient_source_grid_name(transient_ids(1))) == 'grid1')
  CALL test(TRIM(yac_fget_transient_source_grid_name(transient_ids(2))) == 'grid2')
  CALL test(TRIM(yac_fget_transient_target_grid_name(transient_ids(1))) == 'grid2')
  CALL test(TRIM(yac_fget_transient_target_grid_name(transient_ids(2))) == 'grid3')
  CALL test(TRIM(yac_fget_transient_name(transient_ids(1))) == "sea_surface_temperature")
  CALL test(TRIM(yac_fget_transient_name(transient_ids(2))) == "water_flux_into_sea_water")

  CALL test(yac_fget_transients_count(comp_ids(3)) == 0)

  call yac_ffinalize ( );

  call stop_test

  call exit_tests

end program test_get_transients
